==> integration-tests-data-index-service-springboot-1.8.0.Final-sources.jar: org/acme/travels/ApprovalsModelOutput.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.travels;

import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.MappableToModel;
import org.kie.kogito.Model;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "approvals", name = "Approvals", hidden = true)
public class ApprovalsModelOutput implements Model, MappableToModel<ApprovalsModel> {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap<>();
        params.put("approver", this.approver);
        params.put("firstLineApproval", this.firstLineApproval);
        params.put("secondLineApproval", this.secondLineApproval);
        params.put("traveller", this.traveller);
        return params;
    }

    @Override
    public ApprovalsModelOutput fromMap(Map<String, Object> params) {
        return fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(getId(), params);
    }

    public ApprovalsModelOutput fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.approver = (java.lang.String) params.get("approver");
        this.firstLineApproval = (java.lang.Boolean) params.get("firstLineApproval");
        this.secondLineApproval = (java.lang.Boolean) params.get("secondLineApproval");
        this.traveller = (org.acme.travels.Traveller) params.get("traveller");
        return this;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "approver")
    @javax.validation.Valid()
    private java.lang.String approver;

    public java.lang.String getApprover() {
        return approver;
    }

    public void setApprover(java.lang.String approver) {
        this.approver = approver;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "firstLineApproval")
    @javax.validation.Valid()
    private java.lang.Boolean firstLineApproval;

    public java.lang.Boolean getFirstLineApproval() {
        return firstLineApproval;
    }

    public void setFirstLineApproval(java.lang.Boolean firstLineApproval) {
        this.firstLineApproval = firstLineApproval;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "secondLineApproval")
    @javax.validation.Valid()
    private java.lang.Boolean secondLineApproval;

    public java.lang.Boolean getSecondLineApproval() {
        return secondLineApproval;
    }

    public void setSecondLineApproval(java.lang.Boolean secondLineApproval) {
        this.secondLineApproval = secondLineApproval;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "traveller")
    @javax.validation.Valid()
    private org.acme.travels.Traveller traveller;

    public org.acme.travels.Traveller getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.travels.Traveller traveller) {
        this.traveller = traveller;
    }

    @Override()
    public ApprovalsModel toModel() {
        ApprovalsModel result = new ApprovalsModel();
        result.setId(getId());
        result.setApprover(getApprover());
        result.setFirstLineApproval(getFirstLineApproval());
        result.setSecondLineApproval(getSecondLineApproval());
        result.setTraveller(getTraveller());
        return result;
    }
}

==> integration-tests-data-index-service-springboot-1.43.0.Final-sources.jar: org/acme/travels/ApprovalsModelOutput.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.travels;

import org.kie.kogito.MapInput;
import org.kie.kogito.MapInputId;
import org.kie.kogito.MapOutput;
import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.MappableToModel;
import org.kie.kogito.Model;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "approvals", name = "Approvals", hidden = true)
public class ApprovalsModelOutput implements org.kie.kogito.Model, MapInput, MapInputId, MapOutput, MappableToModel<ApprovalsModel> {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "approver")
    @javax.validation.Valid()
    private java.lang.String approver;

    public java.lang.String getApprover() {
        return approver;
    }

    public void setApprover(java.lang.String approver) {
        this.approver = approver;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "firstLineApproval")
    @javax.validation.Valid()
    private java.lang.Boolean firstLineApproval;

    public java.lang.Boolean getFirstLineApproval() {
        return firstLineApproval;
    }

    public void setFirstLineApproval(java.lang.Boolean firstLineApproval) {
        this.firstLineApproval = firstLineApproval;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "secondLineApproval")
    @javax.validation.Valid()
    private java.lang.Boolean secondLineApproval;

    public java.lang.Boolean getSecondLineApproval() {
        return secondLineApproval;
    }

    public void setSecondLineApproval(java.lang.Boolean secondLineApproval) {
        this.secondLineApproval = secondLineApproval;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "traveller")
    @javax.validation.Valid()
    private org.acme.travels.Traveller traveller;

    public org.acme.travels.Traveller getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.travels.Traveller traveller) {
        this.traveller = traveller;
    }

    @Override()
    public ApprovalsModel toModel() {
        ApprovalsModel result = new ApprovalsModel();
        result.setId(getId());
        result.setApprover(getApprover());
        result.setFirstLineApproval(getFirstLineApproval());
        result.setSecondLineApproval(getSecondLineApproval());
        result.setTraveller(getTraveller());
        return result;
    }
}
